==> cucim-23.6.0-py3-none-manylinux2014_x86_64.manylinux_2_17_x86_64.whl: cucim/skimage/color/__init__.py <==
from .colorconv import (ahx_from_rgb, bex_from_rgb, bpx_from_rgb, bro_from_rgb,
                        combine_stains, convert_colorspace, fgx_from_rgb,
                        gdx_from_rgb, gray2rgb, gray2rgba, hax_from_rgb,
                        hdx_from_rgb, hed2rgb, hed_from_rgb, hpx_from_rgb,
                        hsv2rgb, lab2lch, lab2rgb, lab2xyz, lch2lab, luv2rgb,
                        luv2xyz, rbd_from_rgb, rgb2gray, rgb2hed, rgb2hsv,
                        rgb2lab, rgb2luv, rgb2rgbcie, rgb2xyz, rgb2ycbcr,
                        rgb2ydbdr, rgb2yiq, rgb2ypbpr, rgb2yuv, rgb_from_ahx,
                        rgb_from_bex, rgb_from_bpx, rgb_from_bro, rgb_from_fgx,
                        rgb_from_gdx, rgb_from_hax, rgb_from_hdx, rgb_from_hed,
                        rgb_from_hpx, rgb_from_rbd, rgba2rgb, rgbcie2rgb,
                        separate_stains, xyz2lab, xyz2luv, xyz2rgb, ycbcr2rgb,
                        ydbdr2rgb, yiq2rgb, ypbpr2rgb, yuv2rgb)
from .colorlabel import color_dict, label2rgb
from .delta_e import deltaE_cie76, deltaE_ciede94, deltaE_ciede2000, deltaE_cmc

__all__ = ['convert_colorspace',
           'rgba2rgb',
           'rgb2hsv',
           'hsv2rgb',
           'rgb2xyz',
           'xyz2rgb',
           'rgb2rgbcie',
           'rgbcie2rgb',
           'rgb2gray',
           'gray2rgb',
           'gray2rgba',
           'xyz2lab',
           'lab2xyz',
           'lab2rgb',
           'rgb2lab',
           'xyz2luv',
           'luv2xyz',
           'luv2rgb',
           'rgb2luv',
           'rgb2hed',
           'hed2rgb',
           'lab2lch',
           'lch2lab',
           'rgb2yuv',
           'yuv2rgb',
           'rgb2yiq',
           'yiq2rgb',
           'rgb2ypbpr',
           'ypbpr2rgb',
           'rgb2ycbcr',
           'ycbcr2rgb',
           'rgb2ydbdr',
           'ydbdr2rgb',
           'separate_stains',
           'combine_stains',
           'rgb_from_hed',
           'hed_from_rgb',
           'rgb_from_hdx',
           'hdx_from_rgb',
           'rgb_from_fgx',
           'fgx_from_rgb',
           'rgb_from_bex',
           'bex_from_rgb',
           'rgb_from_rbd',
           'rbd_from_rgb',
           'rgb_from_gdx',
           'gdx_from_rgb',
           'rgb_from_hax',
           'hax_from_rgb',
           'rgb_from_bro',
           'bro_from_rgb',
           'rgb_from_bpx',
           'bpx_from_rgb',
           'rgb_from_ahx',
           'ahx_from_rgb',
           'rgb_from_hpx',
           'hpx_from_rgb',
           'color_dict',
           'label2rgb',
           'deltaE_cie76',
           'deltaE_ciede94',
           'deltaE_ciede2000',  # TODO: fix accuracy
           'deltaE_cmc',
           ]

==> cucim-23.8.0-py3-none-manylinux2014_x86_64.manylinux_2_17_x86_64.whl: cucim/skimage/color/__init__.py <==
from .colorconv import (ahx_from_rgb, bex_from_rgb, bpx_from_rgb, bro_from_rgb,
                        combine_stains, convert_colorspace, fgx_from_rgb,
                        gdx_from_rgb, gray2rgb, gray2rgba, hax_from_rgb,
                        hdx_from_rgb, hed2rgb, hed_from_rgb, hpx_from_rgb,
                        hsv2rgb, lab2lch, lab2rgb, lab2xyz, lch2lab, luv2rgb,
                        luv2xyz, rbd_from_rgb, rgb2gray, rgb2hed, rgb2hsv,
                        rgb2lab, rgb2luv, rgb2rgbcie, rgb2xyz, rgb2ycbcr,
                        rgb2ydbdr, rgb2yiq, rgb2ypbpr, rgb2yuv, rgb_from_ahx,
                        rgb_from_bex, rgb_from_bpx, rgb_from_bro, rgb_from_fgx,
                        rgb_from_gdx, rgb_from_hax, rgb_from_hdx, rgb_from_hed,
                        rgb_from_hpx, rgb_from_rbd, rgba2rgb, rgbcie2rgb,
                        separate_stains, xyz2lab, xyz2luv, xyz2rgb,
                        xyz_tristimulus_values, ycbcr2rgb, ydbdr2rgb, yiq2rgb,
                        ypbpr2rgb, yuv2rgb)
from .colorlabel import color_dict, label2rgb
from .delta_e import deltaE_cie76, deltaE_ciede94, deltaE_ciede2000, deltaE_cmc

__all__ = ['convert_colorspace',
           'xyz_tristimulus_values',
           'rgba2rgb',
           'rgb2hsv',
           'hsv2rgb',
           'rgb2xyz',
           'xyz2rgb',
           'rgb2rgbcie',
           'rgbcie2rgb',
           'rgb2gray',
           'gray2rgb',
           'gray2rgba',
           'xyz2lab',
           'lab2xyz',
           'lab2rgb',
           'rgb2lab',
           'xyz2luv',
           'luv2xyz',
           'luv2rgb',
           'rgb2luv',
           'rgb2hed',
           'hed2rgb',
           'lab2lch',
           'lch2lab',
           'rgb2yuv',
           'yuv2rgb',
           'rgb2yiq',
           'yiq2rgb',
           'rgb2ypbpr',
           'ypbpr2rgb',
           'rgb2ycbcr',
           'ycbcr2rgb',
           'rgb2ydbdr',
           'ydbdr2rgb',
           'separate_stains',
           'combine_stains',
           'rgb_from_hed',
           'hed_from_rgb',
           'rgb_from_hdx',
           'hdx_from_rgb',
           'rgb_from_fgx',
           'fgx_from_rgb',
           'rgb_from_bex',
           'bex_from_rgb',
           'rgb_from_rbd',
           'rbd_from_rgb',
           'rgb_from_gdx',
           'gdx_from_rgb',
           'rgb_from_hax',
           'hax_from_rgb',
           'rgb_from_bro',
           'bro_from_rgb',
           'rgb_from_bpx',
           'bpx_from_rgb',
           'rgb_from_ahx',
           'ahx_from_rgb',
           'rgb_from_hpx',
           'hpx_from_rgb',
           'color_dict',
           'label2rgb',
           'deltaE_cie76',
           'deltaE_ciede94',
           'deltaE_ciede2000',  # TODO: fix accuracy
           'deltaE_cmc',
           ]
